LSMTool: the LOFAR Sky Model Tool
=================================

LSMTool is a Python package which allows for the manipulation of LOFAR sky models in the ``makesourcedb`` format.

Contents
========

.. toctree::
   :maxdepth: 2

   overview.rst
   lsmtool.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

